@@ -314,8 +314,8 @@ gconf_client_get_color_with_default (GConfClient* client, const gchar* key,
                       		     const gchar* def, GError** err)
 {
 	gchar *str_color = NULL;
-	GdkColor color;
-	
+	GdkColor color = {0, };
+
 	gedit_debug (DEBUG_PREFS, "");
 
       	g_return_val_if_fail (client != NULL, color);
@@ -364,7 +364,7 @@ gconf_client_set_color (GConfClient* client, const gchar* key,
 static GdkColor
 gedit_prefs_manager_get_color (const gchar* key, const gchar* def)
 {
-	GdkColor color;
+	GdkColor color = {0, };
 
 	gedit_debug (DEBUG_PREFS, "");
 
@@ -526,7 +526,7 @@ DEFINE_BOOL_PREF (create_backup_copy,
 		  GPM_DEFAULT_CREATE_BACKUP_COPY);
 
 /* Backup extension. This is configurable only using gconftool or gconf-editor */
-gchar*	 		\
+gchar *
 gedit_prefs_manager_get_backup_extension (void)
 {
 	gedit_debug (DEBUG_PREFS, "");
@@ -1201,6 +1201,16 @@ gedit_prefs_manager_shown_in_menu_encodings_can_set (void)
 
 }
 
+/* Highlight current line */
+DEFINE_BOOL_PREF (highlight_current_line,
+		  GPM_HIGHLIGHT_CURRENT_LINE,
+		  GPM_DEFAULT_HIGHLIGHT_CURRENT_LINE)
+
+/* Highlight matching bracket */
+DEFINE_BOOL_PREF (bracket_matching,
+		  GPM_BRACKET_MATCHING,
+		  GPM_DEFAULT_BRACKET_MATCHING)
+	
 /* Display Right Margin */
 DEFINE_BOOL_PREF (display_right_margin,
 		  GPM_DISPLAY_RIGHT_MARGIN,
@@ -1378,7 +1388,7 @@ gconf_client_get_string_with_default (GConfClient* client, const gchar* key,
   else
     {
       if (error != NULL)
-        *err = error;
+        handle_error (client, error, err);
       return def ? g_strdup (def) : NULL;
     }
 }
